# Product-specific compile-time definitions.
# Embedian SMARC-FiMX6

include device/embedian/imx6/soc/imx6dq.mk
include device/embedian/smarc_mx6/build_id.mk
include device/embedian/imx6/BoardConfigCommon.mk
include device/fsl-proprietary/gpu-viv/fsl-gpu.mk

# SMARC-FiMX6 default target for EXT4
BUILD_TARGET_FS ?= ext4
include device/embedian/imx6/imx6_target_fs.mk

ifeq ($(BUILD_TARGET_DEVICE),sd)
ADDITIONAL_BUILD_PROPERTIES += \
                        ro.boot.storage_type=sd
ifneq ($(BUILD_TARGET_FS),f2fs)
TARGET_RECOVERY_FSTAB = device/embedian/smarc_mx6/fstab_sd.freescale

# build for ext4
PRODUCT_COPY_FILES +=	\
	device/embedian/smarc_mx6/fstab_sd.freescale:root/fstab.freescale 
else
TARGET_RECOVERY_FSTAB = device/embedian/smarc_mx6/fstab_sd-f2fs.freescale
# build for f2fs
PRODUCT_COPY_FILES +=	\
	device/embedian/smarc_mx6/fstab_sd-f2fs.freescale:root/fstab.freescale 
endif # BUILD_TARGET_FS

else

ADDITIONAL_BUILD_PROPERTIES += \
                        ro.boot.storage_type=emmc
ifneq ($(BUILD_TARGET_FS),f2fs)
TARGET_RECOVERY_FSTAB = device/embedian/smarc_mx6/fstab_emmc.freescale

# build for ext4
PRODUCT_COPY_FILES +=	\
	device/embedian/smarc_mx6/fstab_emmc.freescale:root/fstab.freescale 

else
TARGET_RECOVERY_FSTAB = device/embedian/smarc_mx6/fstab_emmc-f2fs.freescale
# build for f2fs
PRODUCT_COPY_FILES +=	\
	device/embedian/smarc_mx6/fstab_emmc-f2fs.freescale:root/fstab.freescale 

endif # BUILD_TARGET_FS
endif # BUILD_TARGET_DEVICE

BOOTLOADER_USES_SPL := true
TARGET_BOOTLOADER_BOARD_NAME := smarc_mx6
PRODUCT_MODEL := smarc_fimx6

TARGET_RELEASETOOLS_EXTENSIONS := device/embedian/imx6

TARGET_KERNEL_MODULES :=

BOARD_WLAN_VENDOR                	:=
# TI WILINK WIFI
USES_TI_MAC80211 			:= true
ifeq ($(USES_TI_MAC80211),true)
WPA_SUPPLICANT_VERSION         		:= VER_0_8_X
BOARD_WPA_SUPPLICANT_DRIVER    		:= NL80211
BOARD_HOSTAPD_DRIVER           		:= NL80211
BOARD_WPA_SUPPLICANT_PRIVATE_LIB	:= lib_driver_cmd_wl12xx
BOARD_HOSTAPD_PRIVATE_LIB        	:= lib_driver_cmd_wl12xx
BOARD_WLAN_DEVICE                	:= wl12xx_mac80211

BOARD_SOFTAP_DEVICE              	:= wl12xx_mac80211
COMMON_GLOBAL_CFLAGS             	+= -DUSES_TI_MAC80211
COMMON_GLOBAL_CFLAGS             	+= -DANDROID_P2P_STUB
WIFI_FIRMWARE_LOADER             	:= ""
endif

BOARD_MODEM_VENDOR :=

# UNITE is a virtual device.
# BOARD_WLAN_DEVICE            := UNITE
# WPA_SUPPLICANT_VERSION       := VER_0_8_UNITE

# BOARD_WPA_SUPPLICANT_DRIVER  := NL80211
# BOARD_HOSTAPD_DRIVER         := NL80211

# BOARD_HOSTAPD_PRIVATE_LIB_BCM               := lib_driver_cmd_bcmdhd
# BOARD_WPA_SUPPLICANT_PRIVATE_LIB_BCM        := lib_driver_cmd_bcmdhd

# BOARD_SUPPORT_BCM_WIFI  := true
#for intel vendor
# ifeq ($(BOARD_WLAN_VENDOR),INTEL)
# BOARD_WLAN_DEVICE                        := INTEL
# BOARD_HOSTAPD_PRIVATE_LIB                := private_lib_driver_cmd
# BOARD_WPA_SUPPLICANT_PRIVATE_LIB         := private_lib_driver_cmd
# WPA_SUPPLICANT_VERSION                   := VER_0_8_X
# HOSTAPD_VERSION                          := VER_0_8_X
# BOARD_WPA_SUPPLICANT_PRIVATE_LIB         := private_lib_driver_cmd_intel
# WIFI_DRIVER_MODULE_PATH                  := "/system/lib/modules/iwlagn.ko"
# WIFI_DRIVER_MODULE_NAME                  := "iwlagn"
# WIFI_DRIVER_MODULE_PATH                  ?= auto
# endif

# WIFI_DRIVER_FW_PATH_STA        := "/system/etc/firmware/bcm/fw_bcmdhd.bin"
# WIFI_DRIVER_FW_PATH_P2P        := "/system/etc/firmware/bcm/fw_bcmdhd.bin"
# WIFI_DRIVER_FW_PATH_AP         := "/system/etc/firmware/bcm/fw_bcmdhd_apsta.bin"
# WIFI_DRIVER_FW_PATH_PARAM      := "/sys/module/bcmdhd/parameters/firmware_path"

# BOARD_MODEM_VENDOR := AMAZON

USE_ATHR_GPS_HARDWARE := false
USE_QEMU_GPS_HARDWARE := false

#for accelerator sensor, need to define sensor type here
BOARD_HAS_SENSOR := false
SENSOR_MMA8451 := false

# for recovery service (KEY_BACK)
TARGET_SELECT_KEY := 158

# we don't support sparse image.
TARGET_USERIMAGES_SPARSE_EXT_DISABLED := false
DM_VERITY_RUNTIME_CONFIG := true
# uncomment below lins if use NAND
#TARGET_USERIMAGES_USE_UBIFS = true


ifeq ($(TARGET_USERIMAGES_USE_UBIFS),true)
UBI_ROOT_INI := device/embedian/smarc_mx6/ubi/ubinize.ini
TARGET_MKUBIFS_ARGS := -m 4096 -e 516096 -c 4096 -x none
TARGET_UBIRAW_ARGS := -m 4096 -p 512KiB $(UBI_ROOT_INI)
endif

ifeq ($(TARGET_USERIMAGES_USE_UBIFS),true)
ifeq ($(TARGET_USERIMAGES_USE_EXT4),true)
$(error "TARGET_USERIMAGES_USE_UBIFS and TARGET_USERIMAGES_USE_EXT4 config open in same time, please only choose one target file system image")
endif
endif

BOARD_KERNEL_CMDLINE := console=ttymxc4,115200 init=/init video=mxcfb0:dev=ldb,if=RGB24,bpp=32 video=mxcfb1:off video=mxcfb2:off video=mxcfb3:off vmalloc=400M androidboot.console=ttymxc4 consoleblank=0 androidboot.hardware=freescale cma=384M androidboot.selinux=disabled
#BOARD_KERNEL_CMDLINE := console=ttymxc4,115200 init=/init video=mxcfb0:dev=hdmi,1920x1080M@60,if=RGB24,bpp=32 video=mxcfb1:off video=mxcfb2:off video=mxcfb3:off vmalloc=400M androidboot.console=ttymxc4 consoleblank=0 androidboot.hardware=freescale cma=384M androidboot.selinux=disabled

ifeq ($(TARGET_USERIMAGES_USE_UBIFS),true)
#UBI boot command line.
# Note: this NAND partition table must align with MFGTool's config.
BOARD_KERNEL_CMDLINE +=  mtdparts=gpmi-nand:16m(bootloader),16m(bootimg),128m(recovery),-(root) gpmi_debug_init ubi.mtd=3
endif

# atheros 3k BT
BOARD_USE_AR3K_BLUETOOTH :=
# BOARD_BLUETOOTH_BDROID_BUILDCFG_INCLUDE_DIR := device/embedian/smarc_mx6/bluetooth

USE_ION_ALLOCATOR := false
USE_GPU_ALLOCATOR := true

# camera hal v3
IMX_CAMERA_HAL_V3 := true

#define consumer IR HAL support
IMX6_CONSUMER_IR_HAL := false

TARGET_BOOTLOADER_CONFIG := smarcfimx6_quad_1g_ser3_android_defconfig smarcfimx6_quad_2g_ser3_android_defconfig smarcfimx6_dl_1g_ser3_android_defconfig smarcfimx6_solo_ser3_android_defconfig
TARGET_BOARD_DTS_CONFIG := smarcfimx6dq:imx6q-smarcfimx6.dtb smarcfimx6dl:imx6dl-smarcfimx6.dtb smarcfimx6dq-wvga:imx6q-smarcfimx6-wvga.dtb smarcfimx6dl-wvga:imx6dl-smarcfimx6-wvga.dtb smarcfimx6dq-xga:imx6q-smarcfimx6-xga.dtb smarcfimx6dl-xga:imx6dl-smarcfimx6-xga.dtb smarcfimx6dq-wxga:imx6q-smarcfimx6-wxga.dtb smarcfimx6dl-wxga:imx6dl-smarcfimx6-wxga.dtb smarcfimx6dq-1080p:imx6q-smarcfimx6-1080p.dtb smarcfimx6dl-1080p:imx6dl-smarcfimx6-1080p.dtb

BOARD_SEPOLICY_DIRS := \
       device/embedian/imx6/sepolicy \
       device/embedian/smarc_mx6/sepolicy

